@@ -44,7 +44,11 @@ struct _GnomePrintPs
 
   /* current font */
   char *current_font;
-  int current_font_size;
+  double current_font_size;
+
+  /* here follows stuff for printing gnome-text lines */
+  GnomeTextFontHandle cur_font;
+  int cur_size;
 };
 
 struct _GnomePrintPsClass
